@@ -10,6 +10,11 @@ from moai_adk.core.git.branch import generate_branch_name
 from moai_adk.core.git.branch_manager import BranchManager
 from moai_adk.core.git.checkpoint import CheckpointManager
 from moai_adk.core.git.commit import format_commit_message
+from moai_adk.core.git.conflict_detector import (
+    ConflictFile,
+    ConflictSeverity,
+    GitConflictDetector,
+)
 from moai_adk.core.git.event_detector import EventDetector
 from moai_adk.core.git.manager import GitManager
 
@@ -20,4 +25,7 @@ __all__ = [
     "BranchManager",
     "CheckpointManager",
     "EventDetector",
+    "GitConflictDetector",
+    "ConflictFile",
+    "ConflictSeverity",
 ]
