@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# @CODE:OFFLINE-001 | SPEC: SPEC-OFFLINE-SUPPORT-001 | TEST: tests/unit/test_network_detection.py
+# # REMOVED_ORPHAN_CODE:OFFLINE-001 | SPEC: SPEC-OFFLINE-SUPPORT-001 | TEST: tests/unit/test_network_detection.py
 """Project metadata utilities
 
 Project information inquiry (language, Git, SPEC progress, etc.)
@@ -22,9 +22,9 @@ CACHE_DIR_NAME = ".moai/cache"
 
 
 def find_project_root(start_path: str | Path = ".") -> Path:
-    """Find MoAI-ADK project root by searching upward for .moai/config.json
+    """Find MoAI-ADK project root by searching upward for .moai/config/config.json
 
-    Traverses up the directory tree until it finds .moai/config.json or CLAUDE.md,
+    Traverses up the directory tree until it finds .moai/config/config.json or CLAUDE.md,
     which indicates the project root. This ensures cache and other files are
     always created in the correct location, regardless of where hooks execute.
 
@@ -41,21 +41,21 @@ def find_project_root(start_path: str | Path = ".") -> Path:
         Path("/Users/user/my-project")  # Found root 3 levels up
 
     Notes:
-        - Searches for .moai/config.json first (most reliable)
+        - Searches for .moai/config/config.json first (most reliable)
         - Falls back to CLAUDE.md if config.json not found
         - Max depth: 10 levels up (prevent infinite loop)
         - Returns absolute path for consistency
 
     TDD History:
         - RED: 4 test scenarios (root, nested, not found, symlinks)
-        - GREEN: Minimal upward search with .moai/config.json detection
+        - GREEN: Minimal upward search with .moai/config/config.json detection
         - REFACTOR: Add CLAUDE.md fallback, max depth limit, absolute path return
     """
     current = Path(start_path).resolve()
     max_depth = 10  # Prevent infinite loop
 
     for _ in range(max_depth):
-        # Check for .moai/config.json (primary indicator)
+        # Check for .moai/config/config.json (primary indicator)
         if (current / ".moai" / "config.json").exists():
             return current
 
@@ -385,9 +385,9 @@ def get_project_language(cwd: str) -> str:
         Language string in lower-case.
 
     Notes:
-        - Reads ``.moai/config.json`` first for a quick answer.
+        - Reads ``.moai/config/config.json`` first for a quick answer.
         - Falls back to ``detect_language`` if configuration is missing.
-        - Automatically finds project root to locate .moai/config.json
+        - Automatically finds project root to locate .moai/config/config.json
     """
     # Find project root to ensure we read config from correct location
     project_root = find_project_root(cwd)
@@ -406,9 +406,8 @@ def get_project_language(cwd: str) -> str:
     return detect_language(str(project_root))
 
 
-# @CODE:CONFIG-INTEGRATION-001
 def get_version_check_config(cwd: str) -> dict[str, Any]:
-    """Read version check configuration from .moai/config.json
+    """Read version check configuration from .moai/config/config.json
 
     Returns version check settings with sensible defaults.
     Supports frequency-based cache TTL configuration.
@@ -476,7 +475,6 @@ def get_version_check_config(cwd: str) -> dict[str, Any]:
         return defaults
 
 
-# @CODE:NETWORK-DETECT-001
 def is_network_available(timeout_seconds: float = 0.1) -> bool:
     """Quick network availability check using socket.
 
@@ -513,7 +511,6 @@ def is_network_available(timeout_seconds: float = 0.1) -> bool:
         return False
 
 
-# @CODE:VERSION-DETECT-MAJOR-001
 def is_major_version_change(current: str, latest: str) -> bool:
     """Detect if version change is a major version bump.
 
@@ -560,7 +557,6 @@ def is_major_version_change(current: str, latest: str) -> bool:
         return False
 
 
-# @CODE:VERSION-CACHE-INTEGRATION-001
 def get_package_version_info(cwd: str = ".") -> dict[str, Any]:
     """Check MoAI-ADK current and latest version with caching and offline support.
 
@@ -593,7 +589,6 @@ def get_package_version_info(cwd: str = ".") -> dict[str, Any]:
         - RED: 5 test scenarios (network detection, cache integration, offline mode)
         - GREEN: Integrate VersionCache with network detection
         - REFACTOR: Extract cache directory constant, improve error handling
-        - Phase 3: Add release_notes_url and is_major_update fields (@CODE:VERSION-INTEGRATE-FIELDS-001)
     """
     import importlib.util
     import urllib.error
