@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# @CODE:HOOKS-CLARITY-DOCS | SPEC: Individual hook files for better UX
 """UserPromptSubmit Hook: Just-In-Time Document Loading
 
 Claude Code Event: UserPromptSubmit
@@ -31,7 +30,6 @@ def main() -> None:
     Analyzes user prompt patterns and recommends relevant documents:
     - /alfred:1-plan → spec-metadata.md
     - /alfred:2-run → development-guide.md
-    - @TAG mentions → TAG documentation
     - SPEC references → related SPEC files
 
     Exit Codes:
