@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 """
-한국어 문서 마크다운 및 Mermaid 린트 검증 스크립트
+Korean documentation markdown and Mermaid lint validation script
 """
 
 import re
@@ -9,7 +9,7 @@ from collections import defaultdict
 from pathlib import Path
 
 
-# 프로젝트 루트 자동 탐지 (pyproject.toml 또는 .git 기준)
+# Auto-detect project root (based on pyproject.toml or .git)
 def find_project_root(start_path: Path) -> Path:
     current = start_path
     while current != current.parent:
@@ -18,12 +18,12 @@ def find_project_root(start_path: Path) -> Path:
         current = current.parent
     raise RuntimeError("Project root not found")
 
-# 프로젝트 루트 찾기
+# Find project root
 script_path = Path(__file__).resolve()
 project_root = find_project_root(script_path.parent)
 sys.path.insert(0, str(project_root))
 
-# 기본 경로 설정
+# Default path configuration
 DEFAULT_DOCS_PATH = project_root / "docs" / "src" / "ko"
 DEFAULT_REPORT_PATH = project_root / ".moai" / "reports" / "lint_report_ko.txt"
 
@@ -37,11 +37,11 @@ class KoreanDocsLinter:
         self.mermaid_blocks = 0
 
     def lint_all(self):
-        """모든 .md 파일 검증"""
+        """Validate all .md files"""
         md_files = sorted(self.docs_path.rglob("*.md"))
         self.file_count = len(md_files)
 
-        print(f"검사 시작: {self.file_count}개 파일")
+        print(f"Starting validation: {self.file_count} files")
         print("=" * 80)
 
         for md_file in md_files:
@@ -50,33 +50,33 @@ class KoreanDocsLinter:
         return self.generate_report()
 
     def lint_file(self, file_path: Path):
-        """개별 파일 검증"""
+        """Validate individual file"""
         try:
             content = file_path.read_text(encoding='utf-8')
             rel_path = file_path.relative_to(self.docs_path.parent)
 
-            # 1. 헤더 구조
+            # 1. Header structure
             self.check_headers(rel_path, content)
 
-            # 2. 코드 블록
+            # 2. Code blocks
             self.check_code_blocks(rel_path, content)
 
-            # 3. Mermaid 다이어그램
+            # 3. Mermaid diagrams
             self.check_mermaid(rel_path, content)
 
-            # 4. 링크
+            # 4. Links
             self.check_links(rel_path, content)
 
-            # 5. 리스트
+            # 5. Lists
             self.check_lists(rel_path, content)
 
-            # 6. 테이블
+            # 6. Tables
             self.check_tables(rel_path, content)
 
-            # 7. 한글 특화
+            # 7. Korean-specific checks
             self.check_korean_specifics(rel_path, content)
 
-            # 8. 공백
+            # 8. Whitespace
             self.check_whitespace(rel_path, content)
 
         except Exception as e:
@@ -84,11 +84,11 @@ class KoreanDocsLinter:
                 'file': file_path,
                 'line': 'N/A',
                 'type': 'file',
-                'message': f'파일 읽기 오류: {str(e)}'
+                'message': f'File read error: {str(e)}'
             })
 
     def check_headers(self, file_path, content):
-        """헤더 구조 검증"""
+        """Validate header structure"""
         lines = content.split('\n')
         prev_level = 0
         h1_count = 0
@@ -99,7 +99,7 @@ class KoreanDocsLinter:
                 level = len(match.group(1))
                 _title = match.group(2).strip()
 
-                # H1 중복 확인
+                # Check for duplicate H1
                 if level == 1:
                     h1_count += 1
                     h1_line = i
@@ -108,22 +108,22 @@ class KoreanDocsLinter:
                             'file': file_path,
                             'line': i,
                             'type': 'header',
-                            'message': f'H1 중복 (이전: {h1_line}줄, 현재: {i}줄)'
+                            'message': f'Duplicate H1 (previous: line {h1_line}, current: line {i})'
                         })
 
-                # 레벨 건너뛰기 확인
+                # Check for skipped header levels
                 if prev_level > 0 and level > prev_level + 1:
                     self.warnings.append({
                         'file': file_path,
                         'line': i,
                         'type': 'header',
-                        'message': f'헤더 레벨 건너뛰기: H{prev_level} → H{level}'
+                        'message': f'Header level skipped: H{prev_level} → H{level}'
                     })
 
                 prev_level = level
 
     def check_code_blocks(self, file_path, content):
-        """코드 블록 쌍 검증"""
+        """Validate code block pairs"""
         lines = content.split('\n')
         in_code_block = False
         open_line = 0
@@ -144,14 +144,14 @@ class KoreanDocsLinter:
                 'file': file_path,
                 'line': open_line,
                 'type': 'code_block',
-                'message': f'코드 블록 미닫힘 (```{code_lang} 시작이 닫히지 않음)'
+                'message': f'Unclosed code block (```{code_lang} not closed)'
             })
 
     def check_mermaid(self, file_path, content):
-        """Mermaid 다이어그램 검증"""
+        """Validate Mermaid diagrams"""
         lines = content.split('\n')
 
-        # Mermaid 블록 찾기
+        # Find Mermaid blocks
         i = 0
         while i < len(lines):
             if lines[i].strip() == '```mermaid':
@@ -159,7 +159,7 @@ class KoreanDocsLinter:
                 block_lines = []
                 i += 1
 
-                # 블록 끝까지 수집
+                # Collect until block end
                 while i < len(lines) and lines[i].strip() != '```':
                     block_lines.append(lines[i])
                     i += 1
@@ -169,7 +169,7 @@ class KoreanDocsLinter:
                         'file': file_path,
                         'line': block_start + 1,
                         'type': 'mermaid',
-                        'message': 'Mermaid 블록 미닫힘'
+                        'message': 'Unclosed Mermaid block'
                     })
                 else:
                     self.mermaid_blocks += 1
@@ -178,25 +178,25 @@ class KoreanDocsLinter:
             i += 1
 
     def validate_mermaid_content(self, file_path, line_no, content):
-        """Mermaid 블록 내용 검증"""
+        """Validate Mermaid block content"""
         if not content.strip():
             self.errors.append({
                 'file': file_path,
                 'line': line_no,
                 'type': 'mermaid',
-                'message': 'Mermaid 블록이 비어있음'
+                'message': 'Empty Mermaid block'
             })
             return
 
         first_line = content.strip().split('\n')[0]
 
-        # 지원 다이어그램 타입
+        # Supported diagram types
         valid_types = [
             'graph', 'sequenceDiagram', 'stateDiagram', 'stateDiagram-v2',
             'classDiagram', 'erDiagram', 'gantt', 'pie', 'flowchart'
         ]
 
-        # 다이어그램 타입 확인
+        # Check diagram type
         has_valid_type = any(first_line.strip().startswith(t) for t in valid_types)
 
         if not has_valid_type and '%%{init:' not in first_line:
@@ -204,91 +204,91 @@ class KoreanDocsLinter:
                 'file': file_path,
                 'line': line_no,
                 'type': 'mermaid',
-                'message': f'Mermaid 다이어그램 타입 미확인: "{first_line[:50]}"'
+                'message': f'Unrecognized Mermaid diagram type: "{first_line[:50]}"'
             })
 
-        # 기본 노드 정의 패턴 확인
+        # Check basic node definition patterns
         if 'graph' in first_line or 'flowchart' in first_line:
             nodes = set(re.findall(r'(\w+)[\[\(]', content))
             edges = set(re.findall(r'(\w+)\s*(?:-->|---|\.->|==>)', content))
 
-            # 정의되지 않은 노드 참조 (간단한 검사)
+            # Check for undefined node references (simple check)
             for edge_src in edges:
                 if edge_src and edge_src not in nodes and not re.match(r'^[A-Z]+$', edge_src):
                     self.info.append({
                         'file': file_path,
                         'line': line_no,
                         'type': 'mermaid',
-                        'message': f'엣지 시작점이 노드로 정의되지 않음: {edge_src}'
+                        'message': f'Edge source not defined as node: {edge_src}'
                     })
 
     def check_links(self, file_path, content):
-        """링크 검증"""
+        """Validate links"""
         links = re.findall(r'\[([^\]]+)\]\(([^)]+)\)', content)
 
         for text, url in links:
-            # 상대 경로 파일 존재 여부 확인
+            # Check relative path file existence
             if url.startswith('./') or url.startswith('../'):
-                # 앵커 제거
+                # Remove anchor
                 file_url = url.split('#')[0] if '#' in url else url
 
-                if file_url:  # 상대 경로만 확인
+                if file_url:  # Check relative paths only
                     try:
                         target_path = (file_path.parent / file_url).resolve()
-                        # 파일 존재 여부 확인
+                        # Check file existence
                         if not target_path.exists() and file_url:
                             self.warnings.append({
                                 'file': file_path,
                                 'line': 'N/A',
                                 'type': 'link',
-                                'message': f'깨진 링크: [{text}]({url})'
+                                'message': f'Broken link: [{text}]({url})'
                             })
                     except Exception:
                         pass
 
     def check_lists(self, file_path, content):
-        """리스트 포맷 검증"""
+        """Validate list format"""
         lines = content.split('\n')
         list_markers = set()
 
         for i, line in enumerate(lines, 1):
-            # 리스트 마커 추출
+            # Extract list marker
             if match := re.match(r'^(\s*)([*\-+])\s+', line):
                 indent, marker = match.groups()
                 list_markers.add(marker)
 
-                # 들여쓰기 검증 (2 또는 4 스페이스)
+                # Validate indentation (2 or 4 spaces)
                 indent_len = len(indent)
                 if indent_len > 0 and indent_len % 2 != 0:
                     self.info.append({
                         'file': file_path,
                         'line': i,
                         'type': 'list',
-                        'message': f'들여쓰기 홀수: {indent_len}개 스페이스'
+                        'message': f'Odd indentation: {indent_len} spaces'
                     })
 
-        # 혼합 마커 사용
+        # Mixed marker usage
         if len(list_markers) > 1:
             self.info.append({
                 'file': file_path,
                 'line': 'N/A',
                 'type': 'list',
-                'message': f'혼합된 리스트 마커 사용: {", ".join(sorted(list_markers))}'
+                'message': f'Mixed list markers used: {", ".join(sorted(list_markers))}'
             })
 
     def check_tables(self, file_path, content):
-        """테이블 포맷 검증"""
+        """Validate table format"""
         lines = content.split('\n')
 
         for i in range(len(lines) - 1):
             line = lines[i]
 
-            # 테이블 헤더 패턴
+            # Table header pattern
             if '|' in line and line.strip().startswith('|') and '|' in lines[i + 1]:
-                # 현재 줄 칼럼 수
+                # Current line column count
                 current_cols = len([c for c in line.split('|')[1:-1]])
 
-                # 다음 줄이 구분선인지 확인
+                # Check if next line is separator
                 next_line = lines[i + 1]
                 if re.match(r'^\|[\s\-:|]+\|$', next_line):
                     sep_cols = len([c for c in next_line.split('|')[1:-1]])
@@ -298,93 +298,93 @@ class KoreanDocsLinter:
                             'file': file_path,
                             'line': i + 1,
                             'type': 'table',
-                            'message': f'테이블 칼럼 불일치: {current_cols} vs {sep_cols}'
+                            'message': f'Table column mismatch: {current_cols} vs {sep_cols}'
                         })
 
     def check_korean_specifics(self, file_path, content):
-        """한글 특화 검증"""
+        """Korean-specific validation"""
         lines = content.split('\n')
 
         for i, line in enumerate(lines, 1):
-            # 전각 공백
+            # Full-width space (Korean validation rule - PRESERVE)
             if '\u3000' in line:
                 self.warnings.append({
                     'file': file_path,
                     'line': i,
                     'type': 'korean',
-                    'message': '전각 공백 (U+3000) 감지'
+                    'message': '전각 공백 (U+3000) detected'
                 })
 
-            # 전각 괄호
+            # Full-width parentheses (Korean validation rule - PRESERVE)
             if '（' in line or '）' in line:
                 self.info.append({
                     'file': file_path,
                     'line': i,
                     'type': 'korean',
-                    'message': '전각 괄호 사용 감지'
+                    'message': '전각 괄호 usage detected'
                 })
 
-            # 전각 쌍따옴표
+            # Full-width double quotes (Korean validation rule - PRESERVE)
             if '"' in line or '"' in line:
                 self.info.append({
                     'file': file_path,
                     'line': i,
                     'type': 'korean',
-                    'message': '전각 쌍따옴표 사용 감지'
+                    'message': '전각 쌍따옴표 usage detected'
                 })
 
     def check_whitespace(self, file_path, content):
-        """공백 관련 검증"""
+        """Whitespace validation"""
         lines = content.split('\n')
 
         for i, line in enumerate(lines, 1):
-            # 줄 끝 공백
+            # Trailing whitespace
             if line.rstrip() != line:
                 self.warnings.append({
                     'file': file_path,
                     'line': i,
                     'type': 'whitespace',
-                    'message': f'줄 끝 공백 ({len(line) - len(line.rstrip())}개)'
+                    'message': f'Trailing whitespace ({len(line) - len(line.rstrip())} chars)'
                 })
 
-            # 탭 문자
+            # Tab character
             if '\t' in line:
                 self.warnings.append({
                     'file': file_path,
                     'line': i,
                     'type': 'whitespace',
-                    'message': '탭 문자 감지 (스페이스 사용 권장)'
+                    'message': 'Tab character detected (spaces recommended)'
                 })
 
-        # 파일 끝 빈 줄 확인
+        # Check for newline at end of file
         if content and not content.endswith('\n'):
             self.info.append({
                 'file': file_path,
                 'line': 'EOF',
                 'type': 'whitespace',
-                'message': '파일 끝에 줄바꿈 없음'
+                'message': 'No newline at end of file'
             })
 
     def generate_report(self) -> str:
-        """검증 리포트 생성"""
+        """Generate validation report"""
         report = []
 
-        # 헤더
+        # Header
         report.append("=" * 80)
-        report.append("한국어 문서 마크다운 및 Mermaid 린트 검수 리포트")
+        report.append("Korean Documentation Markdown and Mermaid Lint Validation Report")
         report.append("=" * 80)
         report.append("")
 
-        # 통계
-        report.append("## 검수 통계")
-        report.append(f"- 검사 파일: {self.file_count}개")
-        report.append(f"- Mermaid 블록: {self.mermaid_blocks}개")
-        report.append(f"- Errors (Critical): {len(self.errors)}개")
-        report.append(f"- Warnings (High): {len(self.warnings)}개")
-        report.append(f"- Info (Low): {len(self.info)}개")
+        # Statistics
+        report.append("## Validation Statistics")
+        report.append(f"- Files checked: {self.file_count}")
+        report.append(f"- Mermaid blocks: {self.mermaid_blocks}")
+        report.append(f"- Errors (Critical): {len(self.errors)}")
+        report.append(f"- Warnings (High): {len(self.warnings)}")
+        report.append(f"- Info (Low): {len(self.info)}")
         report.append("")
 
-        # 오류별 분류
+        # Classify by error type
         error_by_type = defaultdict(list)
         warning_by_type = defaultdict(list)
         info_by_type = defaultdict(list)
@@ -398,30 +398,30 @@ class KoreanDocsLinter:
         for inf in self.info:
             info_by_type[inf['type']].append(inf)
 
-        # ERROR 상세
+        # ERROR details
         if self.errors:
-            report.append("## 🔴 Errors (Critical - 즉시 수정 필요)")
+            report.append("## Errors (Critical - Immediate Fix Required)")
             report.append("")
 
             for error_type in sorted(error_by_type.keys()):
                 errors = error_by_type[error_type]
-                report.append(f"### {error_type.upper()} ({len(errors)}개)")
+                report.append(f"### {error_type.upper()} ({len(errors)} items)")
                 for err in sorted(errors, key=lambda x: str(x['file'])):
                     line_info = f":{err['line']}" if err['line'] != 'N/A' else ""
                     report.append(f"  - {err['file']}{line_info}")
                     report.append(f"    {err['message']}")
                 report.append("")
 
-        # WARNING 상세
+        # WARNING details
         if self.warnings:
-            report.append("## 🟡 Warnings (High Priority)")
+            report.append("## Warnings (High Priority)")
             report.append("")
 
             for warning_type in sorted(warning_by_type.keys()):
                 warnings = warning_by_type[warning_type]
-                report.append(f"### {warning_type.upper()} ({len(warnings)}개)")
+                report.append(f"### {warning_type.upper()} ({len(warnings)} items)")
 
-                # 파일별로 그룹화
+                # Group by file
                 by_file = defaultdict(list)
                 for warn in warnings:
                     by_file[warn['file']].append(warn)
@@ -433,55 +433,55 @@ class KoreanDocsLinter:
                         report.append(f"    [{line_info}] {warn['message']}")
                 report.append("")
 
-        # INFO 상세
+        # INFO details
         if self.info:
-            report.append("## ℹ️ Info (Low Priority - 선택사항)")
+            report.append("## Info (Low Priority - Optional)")
             report.append("")
 
             for info_type in sorted(info_by_type.keys()):
                 infos = info_by_type[info_type]
-                report.append(f"### {info_type.upper()} ({len(infos)}개)")
+                report.append(f"### {info_type.upper()} ({len(infos)} items)")
 
-                # 파일별로 그룹화
+                # Group by file
                 by_file = defaultdict(list)
                 for inf in infos:
                     by_file[inf['file']].append(inf)
 
                 for file_path in sorted(by_file.keys()):
                     count = len(by_file[file_path])
-                    report.append(f"  {file_path} ({count}개 발견)")
+                    report.append(f"  {file_path} ({count} found)")
                 report.append("")
 
-        # 요약
+        # Summary
         report.append("=" * 80)
-        report.append("## 우선순위별 권장사항")
+        report.append("## Priority-based Recommendations")
         report.append("")
 
         if self.errors:
-            report.append(f"**Priority 1 (Critical)**: {len(self.errors)}개 오류 즉시 수정 필요")
+            report.append(f"**Priority 1 (Critical)**: {len(self.errors)} errors require immediate fix")
             report.append("")
 
         if self.warnings:
-            report.append(f"**Priority 2 (High)**: {len(self.warnings)}개 경고 해결 권장")
+            report.append(f"**Priority 2 (High)**: {len(self.warnings)} warnings should be resolved")
             report.append("")
 
         if self.info:
-            report.append(f"**Priority 3 (Low)**: {len(self.info)}개 정보 항목 검토")
+            report.append(f"**Priority 3 (Low)**: {len(self.info)} info items for review")
             report.append("")
 
         report.append("=" * 80)
 
         return "\n".join(report)
 
-# 실행
+# Execution
 if __name__ == "__main__":
     import argparse
 
-    parser = argparse.ArgumentParser(description='한국어 문서 마크다운 린트 검증')
+    parser = argparse.ArgumentParser(description='Korean documentation markdown lint validation')
     parser.add_argument('--path', type=str, default=str(DEFAULT_DOCS_PATH),
-                       help=f'검사할 문서 경로 (기본값: {DEFAULT_DOCS_PATH})')
+                       help=f'Documentation path to check (default: {DEFAULT_DOCS_PATH})')
     parser.add_argument('--output', type=str, default=str(DEFAULT_REPORT_PATH),
-                       help=f'리포트 저장 경로 (기본값: {DEFAULT_REPORT_PATH})')
+                       help=f'Report save path (default: {DEFAULT_REPORT_PATH})')
 
     args = parser.parse_args()
 
@@ -489,8 +489,8 @@ if __name__ == "__main__":
     report = linter.lint_all()
     print(report)
 
-    # 파일에도 저장
+    # Save to file
     report_path = Path(args.output)
     report_path.parent.mkdir(parents=True, exist_ok=True)
     report_path.write_text(report, encoding='utf-8')
-    print(f"\n리포트 저장됨: {report_path}")
+    print(f"\nReport saved: {report_path}")
